@@ -17,7 +17,7 @@ module Algorithms.BF.Hex where
 import Quipper
 import Quipper.CircLifting
 import QuipperLib.Qram
-import QuipperLib.Arith
+import QuipperLib.Arith hiding (template_symb_plus_)
 
 import Prelude hiding (lookup)
 
