@@ -150,6 +150,9 @@ import qualified Data.IntMap as IntMap
 
 import qualified Data.Traversable as Traversable
 
+import Control.Applicative (Applicative(..))
+import Control.Monad (liftM, ap)
+
 -- ----------------------------------------------------------------------
 -- * List operations
 
@@ -767,6 +770,13 @@ instance Monad Id where
   return a = Id a
   (Id a) >>= b = b a
 
+instance Applicative Id where
+  pure = return
+  (<*>) = ap
+
+instance Functor Id where
+  fmap = liftM
+
 -- ----------------------------------------------------------------------
 -- * Identity types
   
