@@ -11,6 +11,9 @@ module Libraries.Template.ErrorMsgQ where
 
 import Language.Haskell.TH
 
+import Control.Applicative (Applicative(..))
+import Control.Monad (liftM, ap)
+
 -- | Shortcut for 'Either String a'.
 type ErrMsg a = Either String a
 
@@ -25,6 +28,12 @@ instance Monad ErrMsgQ where
                  Left s -> return (Left s)
                  Right r -> let (ErrMsgQ y) = f r in y
 
+instance Applicative ErrMsgQ where
+  pure = return
+  (<*>) = ap
+
+instance Functor ErrMsgQ where
+  fmap = liftM
 
 -- | Set an error message, to be thrown.
 -- Usage:                 
