@@ -4,8 +4,15 @@
 -- 
 -- ======================================================================
 
+{-# LANGUAGE CPP #-}
+
+{-# LANGUAGE StandaloneDeriving #-}
+{-# LANGUAGE DeriveDataTypeable #-}
+
+#if __GLASGOW_HASKELL__ < 780
 {-# LANGUAGE RankNTypes #-}
 {-# LANGUAGE ScopedTypeVariables #-}
+#endif
 
 -- | The standard Haskell module "Data.Typeable" only provides
 -- instances for tuples up to length 7. Since we need larger tuples,
@@ -22,6 +29,14 @@ module Libraries.Typeable where
 
 import Data.Typeable
 
+#if __GLASGOW_HASKELL__ >= 708
+
+deriving instance Typeable (,,,,,,,)
+deriving instance Typeable (,,,,,,,,)
+deriving instance Typeable (,,,,,,,,,)
+
+#else
+
 -- Note: we use scoped type variables so that the typerep is constant;
 -- it can be computed at compile time. Same trick as in
 -- Data.Typeable.Internal.
@@ -39,3 +54,5 @@ instance (Typeable a, Typeable b, Typeable c, Typeable d, Typeable e, Typeable f
   typeOf _ = typerep
     where
       typerep = mkTyCon3 "GHC" "Tuple" "(,,,,,,,,,)" `mkTyConApp` [ typeOf (undefined :: a), typeOf (undefined :: b), typeOf (undefined :: c), typeOf (undefined :: d), typeOf (undefined :: e), typeOf (undefined :: f), typeOf (undefined :: g), typeOf (undefined :: h), typeOf (undefined :: i), typeOf (undefined :: j) ]
+
+#endif
