@@ -12,6 +12,9 @@ import qualified Data.Map as M
 import qualified Data.List as L
 import qualified Libraries.Auxiliary as Q
 
+import Control.Applicative (Applicative(..))
+import Control.Monad (liftM, ap)
+
 -- ----------------------------------------------------------------------
 -- * Simplified circuits
 
@@ -70,6 +73,13 @@ instance Monad Circ where
                                  let (Circ c') = f x in
                                  c' s')
 
+instance Applicative Circ where
+  pure = return
+  (<*>) = ap
+
+instance Functor Circ where
+  fmap = liftM
+
 -- ----------------------------------------------------------------------
 -- * Low-level access functions
 
