@@ -19,6 +19,9 @@ import qualified Data.IntMap.Strict as IM {- containers-0.5.2.1 -}
 
 import qualified Control.DeepSeq as Seq
 
+import Control.Applicative (Applicative(..))
+import Control.Monad (liftM, ap)
+
 import qualified Libraries.Auxiliary as Q
 
 import QuipperLib.ClassicalOptim.Circuit
@@ -307,6 +310,13 @@ instance Monad EvalCirc where
                                  let (EvalCirc c') = f x in
                                  c' s')
 
+instance Applicative EvalCirc where
+  pure = return
+  (<*>) = ap
+
+instance Functor EvalCirc where
+  fmap = liftM
+
 -- ----------------------------------------------------------------------
 -- ** Low-level access functions
 
