@@ -1,4 +1,4 @@
--- This file is part of Quipper. Copyright (C) 2011-2013. Please see the
+-- This file is part of Quipper. Copyright (C) 2011-2014. Please see the
 -- file COPYRIGHT for a list of authors, copyright holders, licensing,
 -- and other details. All rights reserved.
 -- 
@@ -76,7 +76,7 @@ import QuipperLib.GateDecompositions
 import QuipperLib.Synthesis
 
 import Libraries.Auxiliary (optional)
-import Libraries.Synthesis.SymReal
+import Quantum.Synthesis.SymReal
 
 import Control.Monad (when)
 import System.Random
