@@ -50,6 +50,9 @@ import qualified Data.Map as Map
 
 import Data.List (partition)
 
+import Control.Applicative (Applicative(..))
+import Control.Monad (liftM, ap)
+
 import qualified Debug.Trace -- used in tracing the simulation of quipper computations
 
 -- | We define our own trace function that only calls trace if the boolean
@@ -292,6 +295,13 @@ instance (Num n) => Monad (Vector n) where
 	return a = Vector [(a,1)]
 	(Vector ps) >>= f = Vector [(b,i*j) | (a,i) <- ps, (b,j) <- removeVector (f a)] where removeVector (Vector as) = as 
 
+instance (Num n) => Applicative (Vector n) where
+  pure = return
+  (<*>) = ap
+
+instance (Num n) => Functor (Vector n) where
+  fmap = liftM
+
 -- | We can show certain vectors, ignoring any 0 probabilities, and
 -- combining equal terms.
 instance (Show a,Eq a,Num n,Eq n,Show n) => Show (Vector n a) where 
