@@ -45,6 +45,9 @@ import qualified Data.IntMap as IntMap
 
 import Data.Typeable
 
+import Control.Applicative (Applicative(..))
+import Control.Monad (liftM, ap)
+
 -- ----------------------------------------------------------------------
 -- * Quantum circuit data type
 
@@ -665,6 +668,13 @@ instance Monad ReadWrite where
     RW_Read bit cont -> RW_Read bit (\bool -> cont bool >>= g)
     RW_Subroutine name subroutine f' -> RW_Subroutine name subroutine (f' >>= g)
 
+instance Applicative ReadWrite where
+  pure = return
+  (<*>) = ap
+
+instance Functor ReadWrite where
+  fmap = liftM
+
 -- | Transforms a read-write computation into one that behaves identically,
 -- but also returns the list of gates generated.
 -- 
