@@ -39,6 +39,9 @@ import Quipper.Transformer
 import qualified Data.Map as Map
 import Data.Map (Map)
 
+import Control.Applicative (Applicative(..))
+import Control.Monad (liftM, ap)
+
 -- ----------------------------------------------------------------------
 -- * Helper functions
 
@@ -90,6 +93,13 @@ instance Monad LabelMonad where
       (m1, y) = getLabelMonad f idxl
       (m2, z) = getLabelMonad (g y) idxl
 
+instance Applicative LabelMonad where
+  pure = return
+  (<*>) = ap
+
+instance Functor LabelMonad where
+  fmap = liftM
+
 -- | Get the current string and index.
 labelmonad_get_indexlist :: LabelMonad IndexList
 labelmonad_get_indexlist = LabelMonad h where
