@@ -52,7 +52,7 @@ import Data.Maybe
 import Control.Monad(when)
 import Graphics.EasyRender
 import System.IO
-import System.Cmd
+import System.Process
 import System.Directory
 import System.Environment
 import System.Info
